@@ -31,7 +31,6 @@ def celery_k8s_executor_config():
         "job_namespace": Field(
             StringSource,
             is_required=False,
-            default_value="default",
             description=(
                 "The namespace into which to launch new jobs. Note that any "
                 "other Kubernetes resources the Job requires (such as the service account) must be "
@@ -71,12 +70,9 @@ def get_celery_engine_job_config(image_pull_policy=None, additional_env_config_m
             "config": merge_dicts(
                 {
                     "job_namespace": {"env": "DAGSTER_K8S_PIPELINE_RUN_NAMESPACE"},
-                    "env_config_maps": (
-                        [
-                            {"env": "DAGSTER_K8S_PIPELINE_RUN_ENV_CONFIGMAP"},
-                        ]
-                        + (additional_env_config_maps if additional_env_config_maps else [])
-                    ),
+                    "env_config_maps": [
+                        {"env": "DAGSTER_K8S_PIPELINE_RUN_ENV_CONFIGMAP"},
+                    ] + (additional_env_config_maps if additional_env_config_maps else []),
                 },
                 (
                     {
