@@ -9,7 +9,6 @@ from dagster import (
     DagsterEventType,
     DagsterInstance,
     Executor,
-    MetadataEntry,
     _check as check,
     executor,
     multiple_process_executor_requirements,
@@ -21,8 +20,8 @@ from dagster._core.events.log import EventLogEntry
 from dagster._core.events.utils import filter_dagster_events_from_cli_logs
 from dagster._core.execution.plan.objects import StepFailureData, UserFailureData
 from dagster._core.execution.retries import RetryMode
-from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
-from dagster._serdes import pack_value, serialize_dagster_namedtuple, unpack_value
+from dagster._core.storage.dagster_run import DagsterRun, DagsterRunStatus
+from dagster._serdes import pack_value, serialize_value, unpack_value
 from dagster._utils.error import serializable_error_info_from_exc_info
 from dagster_celery.config import DEFAULT_CONFIG, dict_wrapper
 from dagster_celery.core_execution_loop import DELEGATE_MARKER
@@ -31,7 +30,7 @@ from dagster_k8s import DagsterK8sJobConfig, construct_dagster_k8s_job
 from dagster_k8s.client import (
     DagsterK8sAPIRetryLimitExceeded,
     DagsterK8sError,
-    DagsterK8sPipelineStatusException,
+    DagsterK8sJobStatusException,
     DagsterK8sTimeoutError,
     DagsterK8sUnrecoverableAPIError,
     DagsterKubernetesClient,
@@ -102,10 +101,8 @@ def celery_k8s_job_executor(init_context):
 
     if not isinstance(run_launcher, CeleryK8sRunLauncher):
         raise DagsterUnmetExecutorRequirementsError(
-            (
-                "This engine is only compatible with a CeleryK8sRunLauncher; configure the "
-                "CeleryK8sRunLauncher on your instance to use it."
-            ),
+            "This engine is only compatible with a CeleryK8sRunLauncher; configure the "
+            "CeleryK8sRunLauncher on your instance to use it.",
         )
 
     job_config = run_launcher.get_k8s_job_config(
@@ -126,7 +123,7 @@ def celery_k8s_job_executor(init_context):
         include=include,
         retries=retries,
         job_config=job_config,
-        job_namespace=exc_cfg.get("job_namespace"),
+        job_namespace=exc_cfg.get("job_namespace", run_launcher.job_namespace),
         load_incluster_config=exc_cfg.get("load_incluster_config"),
         kubeconfig_file=exc_cfg.get("kubeconfig_file"),
         repo_location_name=exc_cfg.get("repo_location_name"),
@@ -165,7 +162,7 @@ class CeleryK8sJobExecutor(Executor):
             dict(DEFAULT_CONFIG, **check.opt_dict_param(config_source, "config_source"))
         )
         self.job_config = check.inst_param(job_config, "job_config", DagsterK8sJobConfig)
-        self.job_namespace = check.opt_str_param(job_namespace, "job_namespace", default="default")
+        self.job_namespace = check.opt_str_param(job_namespace, "job_namespace")
 
         self.load_incluster_config = check.bool_param(
             load_incluster_config, "load_incluster_config"
@@ -199,21 +196,22 @@ class CeleryK8sJobExecutor(Executor):
 def _submit_task_k8s_job(app, plan_context, step, queue, priority, known_state):
     user_defined_k8s_config = get_user_defined_k8s_config(step.tags)
 
-    pipeline_origin = plan_context.reconstructable_pipeline.get_python_origin()
+    job_origin = plan_context.reconstructable_job.get_python_origin()
 
     execute_step_args = ExecuteStepArgs(
-        pipeline_origin=pipeline_origin,
-        pipeline_run_id=plan_context.pipeline_run.run_id,
+        job_origin=job_origin,
+        run_id=plan_context.dagster_run.run_id,
         step_keys_to_execute=[step.key],
         instance_ref=plan_context.instance.get_ref(),
         retry_mode=plan_context.executor.retries.for_inner_plan(),
         known_state=known_state,
         should_verify_step=True,
+        print_serialized_events=True,
     )
 
     job_config = plan_context.executor.job_config
     if not job_config.job_image:
-        job_config = job_config.with_image(pipeline_origin.repository_origin.container_image)
+        job_config = job_config.with_image(job_origin.repository_origin.container_image)
 
     if not job_config.job_image:
         raise Exception("No image included in either executor config or the dagster job")
@@ -232,14 +230,14 @@ def _submit_task_k8s_job(app, plan_context, step, queue, priority, known_state):
     return task_signature.apply_async(
         priority=priority,
         queue=queue,
-        routing_key="{queue}.execute_step_k8s_job".format(queue=queue),
+        routing_key=f"{queue}.execute_step_k8s_job",
     )
 
 
-def construct_step_failure_event_and_handle(pipeline_run, step_key, err, instance):
+def construct_step_failure_event_and_handle(dagster_run, step_key, err, instance):
     step_failure_event = DagsterEvent(
         event_type_value=DagsterEventType.STEP_FAILURE.value,
-        pipeline_name=pipeline_run.pipeline_name,
+        job_name=dagster_run.job_name,
         step_key=step_key,
         event_specific_data=StepFailureData(
             error=serializable_error_info_from_exc_info(sys.exc_info()),
@@ -249,8 +247,8 @@ def construct_step_failure_event_and_handle(pipeline_run, step_key, err, instanc
     event_record = EventLogEntry(
         user_message=str(err),
         level=logging.ERROR,
-        pipeline_name=pipeline_run.pipeline_name,
-        run_id=pipeline_run.run_id,
+        job_name=dagster_run.job_name,
+        run_id=dagster_run.run_id,
         error_info=None,
         step_key=step_key,
         timestamp=time.time(),
@@ -310,38 +308,38 @@ def create_k8s_job_task(celery_app, **task_kwargs):
 
         api_client = DagsterKubernetesClient.production_client()
         instance = DagsterInstance.from_ref(execute_step_args.instance_ref)
-        pipeline_run = instance.get_run_by_id(execute_step_args.pipeline_run_id)
+        dagster_run = instance.get_run_by_id(execute_step_args.run_id)
 
         check.inst(
-            pipeline_run,
+            dagster_run,
             DagsterRun,
-            "Could not load run {}".format(execute_step_args.pipeline_run_id),
+            f"Could not load run {execute_step_args.run_id}",
         )
         step_key = execute_step_args.step_keys_to_execute[0]
 
         celery_worker_name = self.request.hostname
         celery_pod_name = os.environ.get("HOSTNAME")
         instance.report_engine_event(
-            "Task for step {step_key} picked up by Celery".format(step_key=step_key),
-            pipeline_run,
+            f"Task for step {step_key} picked up by Celery",
+            dagster_run,
             EngineEventData(
-                [
-                    MetadataEntry("Celery worker name", value=celery_worker_name),
-                    MetadataEntry("Celery worker Kubernetes Pod name", value=celery_pod_name),
-                ]
+                {
+                    "Celery worker name": celery_worker_name,
+                    "Celery worker Kubernetes Pod name": celery_pod_name,
+                }
             ),
             CeleryK8sJobExecutor,
             step_key=step_key,
         )
 
-        if pipeline_run.status != DagsterRunStatus.STARTED:
+        if dagster_run.status != DagsterRunStatus.STARTED:
             instance.report_engine_event(
                 "Not scheduling step because dagster run status is not STARTED",
-                pipeline_run,
+                dagster_run,
                 EngineEventData(
-                    [
-                        MetadataEntry("Step key", value=step_key),
-                    ]
+                    {
+                        "Step key": step_key,
+                    }
                 ),
                 CeleryK8sJobExecutor,
                 step_key=step_key,
@@ -349,7 +347,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             return []
 
         # Ensure we stay below k8s name length limits
-        k8s_name_key = get_k8s_job_name(execute_step_args.pipeline_run_id, step_key)
+        k8s_name_key = get_k8s_job_name(execute_step_args.run_id, step_key)
 
         retry_state = execute_step_args.known_state.get_retry_state()
 
@@ -363,6 +361,15 @@ def create_k8s_job_task(celery_app, **task_kwargs):
 
         args = execute_step_args.get_command_args()
 
+        labels = {
+            "dagster/job": dagster_run.job_name,
+            "dagster/op": step_key,
+            "dagster/run-id": execute_step_args.run_id,
+        }
+        if dagster_run.external_job_origin:
+            labels["dagster/code-location"] = (
+                dagster_run.external_job_origin.external_repository_origin.code_location_origin.location_name
+            )
         job = construct_dagster_k8s_job(
             job_config,
             args,
@@ -370,15 +377,11 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             user_defined_k8s_config,
             pod_name,
             component="step_worker",
-            labels={
-                "dagster/job": pipeline_run.pipeline_name,
-                "dagster/op": step_key,
-                "dagster/run-id": execute_step_args.pipeline_run_id,
-            },
+            labels=labels,
             env_vars=[
                 {
                     "name": "DAGSTER_RUN_JOB_NAME",
-                    "value": pipeline_run.job_name,
+                    "value": dagster_run.job_name,
                 },
                 {"name": "DAGSTER_RUN_STEP_KEY", "value": step_key},
             ],
@@ -390,19 +393,17 @@ def create_k8s_job_task(celery_app, **task_kwargs):
         # Post event for starting execution
         job_name = job.metadata.name
         engine_event = instance.report_engine_event(
-            'Executing step "{}" in Kubernetes job {}.'.format(step_key, job_name),
-            pipeline_run,
+            f'Executing step "{step_key}" in Kubernetes job {job_name}.',
+            dagster_run,
             EngineEventData(
-                [
-                    MetadataEntry("Step key", value=step_key),
-                    MetadataEntry("Kubernetes Job name", value=job_name),
-                    MetadataEntry("Job image", value=job_config.job_image),
-                    MetadataEntry("Image pull policy", value=job_config.image_pull_policy),
-                    MetadataEntry("Image pull secrets", value=str(job_config.image_pull_secrets)),
-                    MetadataEntry(
-                        "Service account name", value=str(job_config.service_account_name)
-                    ),
-                ],
+                {
+                    "Step key": step_key,
+                    "Kubernetes Job name": job_name,
+                    "Job image": job_config.job_image,
+                    "Image pull policy": job_config.image_pull_policy,
+                    "Image pull secrets": str(job_config.image_pull_secrets),
+                    "Service account name": str(job_config.service_account_name),
+                },
                 marker_end=DELEGATE_MARKER,
             ),
             CeleryK8sJobExecutor,
@@ -419,12 +420,12 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                 instance.report_engine_event(
                     "Did not create Kubernetes job {} for step {} since job name already "
                     "exists, proceeding with existing job.".format(job_name, step_key),
-                    pipeline_run,
+                    dagster_run,
                     EngineEventData(
-                        [
-                            MetadataEntry("Step key", value=step_key),
-                            MetadataEntry("Kubernetes Job name", value=job_name),
-                        ],
+                        {
+                            "Step key": step_key,
+                            "Kubernetes Job name": job_name,
+                        },
                         marker_end=DELEGATE_MARKER,
                     ),
                     CeleryK8sJobExecutor,
@@ -434,11 +435,11 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                 instance.report_engine_event(
                     "Encountered unexpected error while creating Kubernetes job {} for step {}, "
                     "exiting.".format(job_name, step_key),
-                    pipeline_run,
+                    dagster_run,
                     EngineEventData(
-                        [
-                            MetadataEntry("Step key", value=step_key),
-                        ],
+                        {
+                            "Step key": step_key,
+                        },
                         error=serializable_error_info_from_exc_info(sys.exc_info()),
                     ),
                     CeleryK8sJobExecutor,
@@ -451,24 +452,24 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                 job_name=job_name,
                 namespace=job_namespace,
                 instance=instance,
-                run_id=execute_step_args.pipeline_run_id,
+                run_id=execute_step_args.run_id,
                 wait_timeout=job_wait_timeout,
             )
         except (DagsterK8sError, DagsterK8sTimeoutError) as err:
             step_failure_event = construct_step_failure_event_and_handle(
-                pipeline_run, step_key, err, instance=instance
+                dagster_run, step_key, err, instance=instance
             )
             events.append(step_failure_event)
-        except DagsterK8sPipelineStatusException:
+        except DagsterK8sJobStatusException:
             instance.report_engine_event(
                 "Terminating Kubernetes Job because dagster run status is not STARTED",
-                pipeline_run,
+                dagster_run,
                 EngineEventData(
-                    [
-                        MetadataEntry("Step key", value=step_key),
-                        MetadataEntry("Kubernetes Job name", value=job_name),
-                        MetadataEntry("Kubernetes Job namespace", value=job_namespace),
-                    ]
+                    {
+                        "Step key": step_key,
+                        "Kubernetes Job name": job_name,
+                        "Kubernetes Job namespace": job_namespace,
+                    }
                 ),
                 CeleryK8sJobExecutor,
                 step_key=step_key,
@@ -486,11 +487,11 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             instance.report_engine_event(
                 "Encountered unexpected error while waiting on Kubernetes job {} for step {}, "
                 "exiting.".format(job_name, step_key),
-                pipeline_run,
+                dagster_run,
                 EngineEventData(
-                    [
-                        MetadataEntry("Step key", value=step_key),
-                    ],
+                    {
+                        "Step key": step_key,
+                    },
                     error=serializable_error_info_from_exc_info(sys.exc_info()),
                 ),
                 CeleryK8sJobExecutor,
@@ -504,11 +505,11 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             instance.report_engine_event(
                 "Encountered unexpected error retreiving Pods for Kubernetes job {} for step {}, "
                 "exiting.".format(job_name, step_key),
-                pipeline_run,
+                dagster_run,
                 EngineEventData(
-                    [
-                        MetadataEntry("Step key", value=step_key),
-                    ],
+                    {
+                        "Step key": step_key,
+                    },
                     error=serializable_error_info_from_exc_info(sys.exc_info()),
                 ),
                 CeleryK8sJobExecutor,
@@ -519,8 +520,8 @@ def create_k8s_job_task(celery_app, **task_kwargs):
         # Post engine event for log retrieval
         engine_event = instance.report_engine_event(
             "Retrieving logs from Kubernetes Job pods",
-            pipeline_run,
-            EngineEventData([MetadataEntry("Pod names", value="\n".join(pod_names))]),
+            dagster_run,
+            EngineEventData({"Pod names": "\n".join(pod_names)}),
             CeleryK8sJobExecutor,
             step_key=step_key,
         )
@@ -537,11 +538,11 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                     "Pod name {} for step {}. Will attempt to continue with other pods.".format(
                         job_name, pod_name, step_key
                     ),
-                    pipeline_run,
+                    dagster_run,
                     EngineEventData(
-                        [
-                            MetadataEntry("Step key", value=step_key),
-                        ],
+                        {
+                            "Step key": step_key,
+                        },
                         error=serializable_error_info_from_exc_info(sys.exc_info()),
                     ),
                     CeleryK8sJobExecutor,
@@ -549,7 +550,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                 )
 
         events += filter_dagster_events_from_cli_logs(logs)
-        serialized_events = [serialize_dagster_namedtuple(event) for event in events]
+        serialized_events = [serialize_value(event) for event in events]
         return serialized_events
 
     return _execute_step_k8s_job
